# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to tweak the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

# Pick up the right dictionary for the spell check
%if 0%{?fedora} > 8 || 0%{?rhel} > 5
%global speller hunspell
%else
%global speller aspell
%endif

Name:		perl-constant-boolean
Version:	0.02
Release:	17.%{__distinit}%{__distvers}
Summary:	Define TRUE and FALSE constants
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/constant-boolean/
Source0:	http://search.cpan.org/CPAN/authors/id/D/DE/DEXTER/constant-boolean-%{version}.tar.gz
Source1:	C0B10A5B.pub
Patch0:		constant-boolean-0.02-Critic.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gnupg
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(strict)
BuildRequires:	perl(Symbol::Util)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Carp)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::Harness)
BuildRequires:	perl(Test::More)
# Release Tests
BuildRequires:	patchutils
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Slurp)
BuildRequires:	perl(Test::CheckChanges)
BuildRequires:	perl(Test::Distribution)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
BuildRequires:	perl(Test::Signature)
BuildRequires:	perl(Test::Spelling), %{speller}-en
BuildRequires:	sed
# Dependencies
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	perl(Symbol::Util)

%description
Defines TRUE and FALSE constants in caller's namespace. You could use
simple values like empty string or zero for false, or any non-empty and non-
zero string value as true, but the TRUE and FALSE constants are more
descriptive.

%prep
%setup -q -c -n constant-boolean

# Copy up documentation for convenience with %%doc
cp -a constant-boolean-%{version}/{Changes,LICENSE,README} .

# Create a GPG directory for testing, to avoid using ~/.gnupg
mkdir --mode=0700 gnupghome
GNUPGHOME=$(pwd)/gnupghome gpg --import %{SOURCE1}

%build
cd constant-boolean-%{version}
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}
cd -

%install
rm -rf %{buildroot}
make -C constant-boolean-%{version} pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
export GNUPGHOME=$(pwd)/gnupghome
cd constant-boolean-%{version}

# === MAIN TEST SUITE === #
make test

# ===  RELEASE TESTS  === #
RELEASE_TESTS="$(echo xt/*.t | sed 's|xt/copyright.t||')"
# Don't run the copyright test as it will fail after the year of module release
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/copyright.t||')"
# Don't run the perlcritic test yet as we need to patch the code
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/perlcritic.t||')"
# Changes test needs tweaking if we don't have Test::More ≥ 0.88,
# but don't do it yet as it would cause the signature test to fail
%if %{old_test_more}
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/check_changes.t||')"
%endif
# Signature test would fail on recent distros due to presence of MYMETA.json/MYMETA.yml
[ -f MYMETA.json ] && mv MYMETA.json ..
[ -f MYMETA.yml ] && mv MYMETA.yml ..
make test TEST_FILES="$RELEASE_TESTS"
[ -f ../MYMETA.json ] && mv ../MYMETA.json .
[ -f ../MYMETA.yml ] && mv ../MYMETA.yml .
# Patch the code to turn off one check before running the perlcritic test
patch -p0 < %{P:0}
make test TEST_FILES=xt/perlcritic.t
patch -p0 -R < %{P:0}
# Now try the Changes test if we didn't run it before
%if %{old_test_more}
sed -e 's|^use Test::CheckChanges;|use Test::More tests => 1;\n&|' xt/check_changes.t > xt/check_changes_compat.t
make test TEST_FILES=xt/check_changes_compat.t
rm xt/check_changes_compat.t
%endif

cd -

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README
%{perl_vendorlib}/constant/
%{_mandir}/man3/constant::boolean.3*

%changelog
* Wed Aug 10 2016 Paul Howarth <paul@city-fan.org> - 0.02-17
- Fix FTBFS when perl is not in the minimal buildroot
- Classify buildreqs by usage
- Simplify find command using -delete

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 0.02-13
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Thu Jul 25 2013 Paul Howarth <paul@city-fan.org> - 0.02-10
- Perl 5.18 rebuild

* Mon Jul  1 2013 Paul Howarth <paul@city-fan.org> - 0.02-8
- Tweak the perlcritic test, which has discovered something to moan about

* Sun Jul 15 2012 Paul Howarth <paul@city-fan.org> - 0.02-7
- Add runtime dependency on perl(Symbol::Util)
- BR: perl(Carp), perl(Cwd), perl(File::Spec) and perl(Test::Harness)
- Work around release test failure due to presence of MYMETA.json
- Specify version requirements for Test::Pod and Test::Pod::Coverage
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Test::Perl::Critic is always available
  - aspell-en-gb is never needed
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jul 27 2011 Paul Howarth <paul@city-fan.org> - 0.02-5
- Rebuild for perl 5.14.1 in Rawhide
- Work around auto-generated MYMETA file breaking signature test
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri May  6 2011 Paul Howarth <paul@city-fan.org> - 0.02-4
- Import from Fedora

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.02-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 15 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.02-2
- Rebuild to fix problems with vendorarch/lib (#661697)

* Fri May 07 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.02-1
- Update to 0.02

* Fri Apr 30 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.01-6
- Mass rebuild with perl-5.12.0

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 0.01-5
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.01-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.01-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Feb 01 2009 Allisson Azevedo <allisson@gmail.com> - 0.01-2
- Rebuild

* Thu Jan 29 2009 Allisson Azevedo <allisson@gmail.com> 0.01-1
- Initial rpm release
